@@ -55,7 +55,7 @@ def run_implement(exp, pipeline_depth):
 def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
     comp_path = config['comp_path']
     comp_name = config['top_level_comp']
-    clock_period = int(config['period'])
+    clock_period = float(config['period'])
     part = config['part'] if 'part' in config else DEFAULT_PART
     standard = config['standard'] if 'standard' in config else DEFAULT_STANDARD
     includes = parse_includes(config['includes'], config_path) if 'includes' in config else []
