@@ -74,7 +74,7 @@ def minimize_latency(exp_settings: vivado_exp.Experiment, handlers):
             mid = low + (up - low) // 2
         logger.info(f"Running the experiment with a pipeline depth constraint of {mid}")
         ret = exp_settings.run_exp(
-            depth_constraint=mid,
+            depth_constraint=(1 if mid == 2 else mid),
             suffix = f"_{mid}"
         ).get_results()
 
