@@ -2,7 +2,6 @@
 Parse vivado hls report
 """
 
-from itertools import dropwhile
 from pathlib import Path
 import re
 from xml.dom import minidom
@@ -25,24 +24,20 @@ def parse_syn_report(synth_report_file):
     res['estimated_period'] = __getText(estimated_clk.childNodes)
     try:
         pipeline_depth = tree.getElementsByTagName('Worst-caseLatency')[0]
-        res['worst_case_latency'] = __getText(pipeline_depth.childNodes)
+        # Remove one cycle due to the return value register
+        res['worst_case_latency'] = int(__getText(pipeline_depth.childNodes))
     except (KeyError, IndexError, ValueError):
-        res['worst_case_latency'] = '0'
+        res['worst_case_latency'] = 0
     try:
         pipeline_II = tree.getElementsByTagName('PipelineInitiationInterval')[0]
-        res['II'] = __getText(pipeline_II.childNodes)
+        res['II'] = int(__getText(pipeline_II.childNodes))
         res['pipelined'] = True
     except (KeyError, IndexError, ValueError):
-        res['II'] = '0'
+        res['II'] = 0
         res['pipelined'] = False
     return res
 
-def _parse_timing(line):
-    pattern = '(?P<val>[0-9]+\.[0-9]+)ns'
-    match = re.search(pattern, line)
-    return match.group('val')
-
-def parse_impl_report(impl_report_file, timing_report_file):
+def parse_impl_report(impl_report_file):
     impl_file = Path(impl_report_file)
     res = {}
     with impl_file.open("r") as impl:
@@ -53,12 +48,7 @@ def parse_impl_report(impl_report_file, timing_report_file):
     res["DSP"] = __getText(resources.getElementsByTagName('DSP')[0].childNodes)
     res["BRAM"] = __getText(resources.getElementsByTagName('BRAM')[0].childNodes)
     res["SRL"] = __getText(resources.getElementsByTagName('SRL')[0].childNodes)
-    timing_report_path = Path(timing_report_file)
-    line_filter = lambda x : not x.startswith('Max Delay Paths')
-    with timing_report_path.open('r') as timing_report:
-        for line in dropwhile(line_filter,  timing_report):
-            if line.strip().startswith('Data Path Delay:'):
-                res['timing'] = _parse_timing(line)
-                return res
+    timing = tree.getElementsByTagName('TimingReport')[0]
+    res["timing"] = __getText(timing.getElementsByTagName('AchievedClockPeriod')[0].childNodes)
     return res
 
